@@ -16,6 +16,7 @@
 
 package org.drools.workbench.screens.dtablexls.client.editor;
 
+import java.io.InputStream;
 import java.util.List;
 import java.util.Optional;
 
@@ -33,6 +34,7 @@ import org.drools.workbench.screens.dtablexls.service.DecisionTableXLSService;
 import org.guvnor.common.services.project.client.context.WorkspaceProjectContext;
 import org.guvnor.common.services.project.client.security.ProjectController;
 import org.guvnor.common.services.project.model.WorkspaceProject;
+import org.guvnor.common.services.shared.metadata.MetadataService;
 import org.guvnor.common.services.shared.metadata.model.Metadata;
 import org.guvnor.common.services.shared.metadata.model.Overview;
 import org.guvnor.common.services.shared.validation.model.ValidationMessage;
@@ -50,18 +52,24 @@ import org.kie.workbench.common.widgets.metadata.client.validation.AssetUpdateVa
 import org.kie.workbench.common.widgets.metadata.client.widget.OverviewWidgetPresenter;
 import org.mockito.InjectMocks;
 import org.mockito.Mock;
+import org.mockito.Mockito;
 import org.mockito.Spy;
 import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.backend.vfs.Path;
+import org.uberfire.client.promise.Promises;
 import org.uberfire.ext.editor.commons.client.history.VersionRecordManager;
 import org.uberfire.ext.editor.commons.client.menu.BasicFileMenuBuilder;
 import org.uberfire.ext.widgets.common.client.common.BusyIndicatorView;
 import org.uberfire.ext.widgets.common.client.common.ConcurrentChangePopup;
+import org.uberfire.mocks.CallerMock;
+import org.uberfire.mocks.EventSourceMock;
 import org.uberfire.mvp.PlaceRequest;
+import org.uberfire.promise.SyncPromises;
 import org.uberfire.workbench.model.menu.MenuItem;
 
 import static org.junit.Assert.assertNull;
 import static org.mockito.Matchers.any;
+import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.doNothing;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
@@ -126,13 +134,21 @@ public class DecisionTableXLSEditorPresenterTest {
     @Mock
     AlertsButtonMenuItemBuilder alertsButtonMenuItemBuilder;
 
+    Promises promises;
+
     @Mock
     MenuItem alertsButtonMenuItem;
 
+    @Mock
+    MetadataService metadataService;
+
     DecisionTableXLSEditorPresenter presenter;
 
+    Metadata metadata = new Metadata();
+
     @Before
     public void setUp() throws Exception {
+        promises = new SyncPromises();
 
         when(decisionTableXLSResourceType.getSuffix()).thenReturn("XLS");
         when(decisionTableXLSResourceType.accept(XLSPath)).thenReturn(true);
@@ -149,7 +165,8 @@ public class DecisionTableXLSEditorPresenterTest {
                                                             decisionTableXLSXResourceType,
                                                             busyIndicatorView,
                                                             validationPopup,
-                                                            new ServiceMock()
+                                                            new ServiceMock(),
+                                                            new CallerMock<>(metadataService)
         ) {
             {
                 kieView = mock(KieEditorWrapperView.class);
@@ -160,6 +177,9 @@ public class DecisionTableXLSEditorPresenterTest {
                 workbenchContext = DecisionTableXLSEditorPresenterTest.this.workbenchContext;
                 versionRecordManager = DecisionTableXLSEditorPresenterTest.this.versionRecordManager;
                 alertsButtonMenuItemBuilder = DecisionTableXLSEditorPresenterTest.this.alertsButtonMenuItemBuilder;
+                promises = DecisionTableXLSEditorPresenterTest.this.promises;
+                metadata = DecisionTableXLSEditorPresenterTest.this.metadata;
+                notification = mock(EventSourceMock.class);
             }
 
             @Override
@@ -181,7 +201,7 @@ public class DecisionTableXLSEditorPresenterTest {
 
         verify(view).init(presenter);
         verify(view).setupUploadWidget(decisionTableXLSResourceType);
-        verify(view).setPath(any(Path.class));
+        verify(view).setPath(any());
         verify(view).setReadOnly(false);
     }
 
@@ -192,7 +212,7 @@ public class DecisionTableXLSEditorPresenterTest {
 
         verify(view).init(presenter);
         verify(view).setupUploadWidget(decisionTableXLSXResourceType);
-        verify(view).setPath(any(Path.class));
+        verify(view).setPath(any());
         verify(view).setReadOnly(false);
     }
 
@@ -215,6 +235,7 @@ public class DecisionTableXLSEditorPresenterTest {
                                                             null,
                                                             busyIndicatorView,
                                                             null,
+                                                            null,
                                                             null) {
             {
                 concurrentUpdateSessionInfo = mock(ObservablePath.OnConcurrentUpdateEvent.class);
@@ -243,16 +264,16 @@ public class DecisionTableXLSEditorPresenterTest {
     @Test
     public void testMakeMenuBar() {
         doReturn(Optional.of(mock(WorkspaceProject.class))).when(workbenchContext).getActiveWorkspaceProject();
-        doReturn(true).when(projectController).canUpdateProject(any());
+        doReturn(promises.resolve(true)).when(projectController).canUpdateProject(any());
 
         presenter.makeMenuBar();
 
-        verify(fileMenuBuilder).addCopy(any(Path.class),
-                                        any(AssetUpdateValidator.class));
-        verify(fileMenuBuilder).addRename(any(Path.class),
-                                          any(AssetUpdateValidator.class));
-        verify(fileMenuBuilder).addDelete(any(Path.class),
-                                          any(AssetUpdateValidator.class));
+        verify(fileMenuBuilder).addCopy(Mockito.<Path>any(),
+                                        any());
+        verify(fileMenuBuilder).addRename(Mockito.<Path>any(),
+                                          any());
+        verify(fileMenuBuilder).addDelete(Mockito.<Path>any(),
+                                          any());
         verify(fileMenuBuilder).addNewTopLevelMenu(alertsButtonMenuItem);
         verify(presenter).addDownloadMenuItem(fileMenuBuilder);
 
@@ -261,10 +282,12 @@ public class DecisionTableXLSEditorPresenterTest {
     @Test
     public void testMakeMenuBarWithoutUpdateProjectPermission() {
         doReturn(Optional.of(mock(WorkspaceProject.class))).when(workbenchContext).getActiveWorkspaceProject();
-        doReturn(false).when(projectController).canUpdateProject(any());
+        doReturn(promises.resolve(false)).when(projectController).canUpdateProject(any());
 
         presenter.makeMenuBar();
 
+        verify(fileMenuBuilder,
+               never()).addSave(any(MenuItem.class));
         verify(fileMenuBuilder,
                never()).addCopy(any(Path.class),
                                 any(AssetUpdateValidator.class));
@@ -277,6 +300,24 @@ public class DecisionTableXLSEditorPresenterTest {
         verify(fileMenuBuilder).addNewTopLevelMenu(alertsButtonMenuItem);
     }
 
+    @Test
+    public void testSave() {
+        final ObservablePath path = mock(ObservablePath.class);
+        doReturn(path).when(versionRecordManager).getCurrentPath();
+
+        presenter.onStartup(XLSPath,
+                            mock(PlaceRequest.class));
+
+        doReturn(Optional.of(mock(WorkspaceProject.class))).when(workbenchContext).getActiveWorkspaceProject();
+        doReturn(promises.resolve(false)).when(projectController).canUpdateProject(any());
+
+        presenter.save("saving");
+
+        verify(metadataService).saveMetadata(eq(path),
+                                             eq(metadata),
+                                             eq("saving"));
+    }
+
     private class ServiceMock
             implements Caller<DecisionTableXLSService> {
 
@@ -313,7 +354,7 @@ public class DecisionTableXLSEditorPresenterTest {
             public DecisionTableXLSContent loadContent(Path path) {
                 DecisionTableXLSContent content = new DecisionTableXLSContent();
                 content.setOverview(new Overview() {{
-                    setMetadata(mock(Metadata.class));
+                    setMetadata(metadata);
                 }});
                 remoteCallback.callback(content);
                 return null;
@@ -324,6 +365,14 @@ public class DecisionTableXLSEditorPresenterTest {
                 return null;
             }
 
+            @Override
+            public Path create(Path resource,
+                               InputStream content,
+                               String sessionId,
+                               String comment) {
+                return null;
+            }
+
             @Override
             public Path copy(Path path,
                              String newName,
