@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -19,8 +19,6 @@ package org.drools.workbench.screens.guided.dtable.client.widget.table.model.syn
 import java.util.Collections;
 import java.util.List;
 
-import org.drools.workbench.models.datamodel.oracle.DataType;
-import org.drools.workbench.models.datamodel.oracle.ModelField;
 import org.drools.workbench.models.datamodel.rule.BaseSingleFieldConstraint;
 import org.drools.workbench.models.guided.dtable.shared.model.ActionSetFieldCol52;
 import org.drools.workbench.models.guided.dtable.shared.model.BaseColumnFieldDiff;
@@ -30,8 +28,10 @@ import org.drools.workbench.screens.guided.dtable.client.widget.table.columns.Ba
 import org.drools.workbench.screens.guided.dtable.client.widget.table.columns.BooleanUiColumn;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.columns.IntegerUiColumn;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.columns.StringUiColumn;
-import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.ModelSynchronizer;
+import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.ModelSynchronizer.VetoException;
 import org.junit.Test;
+import org.kie.soup.project.datamodel.oracle.DataType;
+import org.kie.soup.project.datamodel.oracle.ModelField;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracle;
 import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridCellValue;
@@ -63,7 +63,7 @@ public class ActionSetFieldColumnSynchronizerTest extends BaseSynchronizerTest {
     }
 
     @Test
-    public void testAppend() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testAppend() throws VetoException {
         //Add a Pattern to be updated
         final Pattern52 pattern = new Pattern52();
         pattern.setBoundName("$a");
@@ -90,15 +90,15 @@ public class ActionSetFieldColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals(1,
                      model.getActionCols().size());
 
-        assertEquals(4,
+        assertEquals(5,
                      uiModel.getColumns().size());
-        assertTrue(uiModel.getColumns().get(3) instanceof IntegerUiColumn);
+        assertTrue(uiModel.getColumns().get(4) instanceof IntegerUiColumn);
         assertEquals(true,
-                     ((BaseSingletonDOMElementUiColumn) uiModel.getColumns().get(2)).isEditable());
+                     ((BaseSingletonDOMElementUiColumn) uiModel.getColumns().get(3)).isEditable());
     }
 
     @Test
-    public void testAppendBoolean() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testAppendBoolean() throws VetoException {
         //Add a Pattern to be updated
         final Pattern52 pattern = new Pattern52();
         pattern.setBoundName("$a");
@@ -126,21 +126,21 @@ public class ActionSetFieldColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals(1,
                      model.getActionCols().size());
 
-        assertEquals(4,
+        assertEquals(5,
                      uiModel.getColumns().size());
-        assertTrue(uiModel.getColumns().get(3) instanceof BooleanUiColumn);
+        assertTrue(uiModel.getColumns().get(4) instanceof BooleanUiColumn);
         assertEquals(true,
-                     ((BaseSingletonDOMElementUiColumn) uiModel.getColumns().get(2)).isEditable());
+                     ((BaseSingletonDOMElementUiColumn) uiModel.getColumns().get(3)).isEditable());
 
         //Test row append (boolean cells should be instantiated for Model and UiModel)
         modelSynchronizer.appendRow();
 
-        assertFalse(model.getData().get(0).get(3).getBooleanValue());
-        assertFalse(((Boolean) uiModel.getRow(0).getCells().get(3).getValue().getValue()));
+        assertFalse(model.getData().get(0).get(4).getBooleanValue());
+        assertFalse(((Boolean) uiModel.getRow(0).getCells().get(4).getValue().getValue()));
     }
 
     @Test
-    public void testUpdate() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testUpdate() throws VetoException {
         //Add a Pattern to be updated
         final Pattern52 pattern = new Pattern52();
         pattern.setBoundName("$a");
@@ -180,17 +180,17 @@ public class ActionSetFieldColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals(1,
                      model.getActionCols().size());
 
-        assertEquals(4,
+        assertEquals(5,
                      uiModel.getColumns().size());
-        assertTrue(uiModel.getColumns().get(3) instanceof StringUiColumn);
+        assertTrue(uiModel.getColumns().get(4) instanceof StringUiColumn);
         assertEquals("updated",
-                     uiModel.getColumns().get(3).getHeaderMetaData().get(1).getTitle());
+                     uiModel.getColumns().get(4).getHeaderMetaData().get(1).getTitle());
         assertEquals(false,
-                     uiModel.getColumns().get(3).isVisible());
+                     uiModel.getColumns().get(4).isVisible());
     }
 
     @Test
-    public void testDelete() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testDelete() throws VetoException {
         //Add a Pattern to be updated
         final Pattern52 pattern = new Pattern52();
         pattern.setBoundName("$a");
@@ -216,7 +216,7 @@ public class ActionSetFieldColumnSynchronizerTest extends BaseSynchronizerTest {
                      model.getConditions().size());
         assertEquals(1,
                      model.getActionCols().size());
-        assertEquals(4,
+        assertEquals(5,
                      uiModel.getColumns().size());
 
         modelSynchronizer.deleteColumn(column);
@@ -224,12 +224,12 @@ public class ActionSetFieldColumnSynchronizerTest extends BaseSynchronizerTest {
                      model.getConditions().size());
         assertEquals(0,
                      model.getActionCols().size());
-        assertEquals(3,
+        assertEquals(4,
                      uiModel.getColumns().size());
     }
 
     @Test
-    public void testMoveColumnTo_MoveLeft() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testMoveColumnTo_MoveLeft() throws VetoException {
         //Add a Pattern to be updated
         final Pattern52 pattern = new Pattern52();
         pattern.setBoundName("$a");
@@ -257,12 +257,12 @@ public class ActionSetFieldColumnSynchronizerTest extends BaseSynchronizerTest {
         modelSynchronizer.appendColumn(column2);
 
         modelSynchronizer.appendRow();
-        uiModel.setCell(0,
-                        3,
-                        new BaseGridCellValue<Integer>(45));
-        uiModel.setCell(0,
-                        4,
-                        new BaseGridCellValue<String>("Smurf"));
+        uiModel.setCellValue(0,
+                             4,
+                             new BaseGridCellValue<Integer>(45));
+        uiModel.setCellValue(0,
+                             5,
+                             new BaseGridCellValue<String>("Smurf"));
 
         assertEquals(2,
                      model.getActionCols().size());
@@ -271,14 +271,14 @@ public class ActionSetFieldColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals(column2,
                      model.getActionCols().get(1));
         assertEquals(45,
-                     model.getData().get(0).get(3).getNumericValue());
+                     model.getData().get(0).get(4).getNumericValue());
         assertEquals("Smurf",
-                     model.getData().get(0).get(4).getStringValue());
+                     model.getData().get(0).get(5).getStringValue());
 
-        assertEquals(5,
+        assertEquals(6,
                      uiModel.getColumns().size());
-        final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(3);
-        final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(5);
         assertEquals("$a",
                      uiModelColumn1_1.getHeaderMetaData().get(0).getTitle());
         assertEquals("age",
@@ -289,16 +289,16 @@ public class ActionSetFieldColumnSynchronizerTest extends BaseSynchronizerTest {
                      uiModelColumn2_1.getHeaderMetaData().get(1).getTitle());
         assertTrue(uiModelColumn1_1 instanceof IntegerUiColumn);
         assertTrue(uiModelColumn2_1 instanceof StringUiColumn);
-        assertEquals(3,
-                     uiModelColumn1_1.getIndex());
         assertEquals(4,
+                     uiModelColumn1_1.getIndex());
+        assertEquals(5,
                      uiModelColumn2_1.getIndex());
         assertEquals(45,
                      uiModel.getRow(0).getCells().get(uiModelColumn1_1.getIndex()).getValue().getValue());
         assertEquals("Smurf",
                      uiModel.getRow(0).getCells().get(uiModelColumn2_1.getIndex()).getValue().getValue());
 
-        uiModel.moveColumnTo(3,
+        uiModel.moveColumnTo(4,
                              uiModelColumn2_1);
 
         assertEquals(2,
@@ -308,14 +308,14 @@ public class ActionSetFieldColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals(column1,
                      model.getActionCols().get(1));
         assertEquals("Smurf",
-                     model.getData().get(0).get(3).getStringValue());
+                     model.getData().get(0).get(4).getStringValue());
         assertEquals(45,
-                     model.getData().get(0).get(4).getNumericValue());
+                     model.getData().get(0).get(5).getNumericValue());
 
-        assertEquals(5,
+        assertEquals(6,
                      uiModel.getColumns().size());
-        final GridColumn<?> uiModelColumn1_2 = uiModel.getColumns().get(3);
-        final GridColumn<?> uiModelColumn2_2 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn1_2 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn2_2 = uiModel.getColumns().get(5);
         assertEquals("$a",
                      uiModelColumn1_2.getHeaderMetaData().get(0).getTitle());
         assertEquals("name",
@@ -326,9 +326,9 @@ public class ActionSetFieldColumnSynchronizerTest extends BaseSynchronizerTest {
                      uiModelColumn2_2.getHeaderMetaData().get(1).getTitle());
         assertTrue(uiModelColumn1_2 instanceof StringUiColumn);
         assertTrue(uiModelColumn2_2 instanceof IntegerUiColumn);
-        assertEquals(4,
+        assertEquals(5,
                      uiModelColumn1_2.getIndex());
-        assertEquals(3,
+        assertEquals(4,
                      uiModelColumn2_2.getIndex());
         assertEquals("Smurf",
                      uiModel.getRow(0).getCells().get(uiModelColumn1_2.getIndex()).getValue().getValue());
@@ -337,7 +337,7 @@ public class ActionSetFieldColumnSynchronizerTest extends BaseSynchronizerTest {
     }
 
     @Test
-    public void testMoveColumnTo_MoveRight() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testMoveColumnTo_MoveRight() throws VetoException {
         //Add a Pattern to be updated
         final Pattern52 pattern = new Pattern52();
         pattern.setBoundName("$a");
@@ -365,12 +365,12 @@ public class ActionSetFieldColumnSynchronizerTest extends BaseSynchronizerTest {
         modelSynchronizer.appendColumn(column2);
 
         modelSynchronizer.appendRow();
-        uiModel.setCell(0,
-                        3,
-                        new BaseGridCellValue<Integer>(45));
-        uiModel.setCell(0,
-                        4,
-                        new BaseGridCellValue<String>("Smurf"));
+        uiModel.setCellValue(0,
+                             4,
+                             new BaseGridCellValue<Integer>(45));
+        uiModel.setCellValue(0,
+                             5,
+                             new BaseGridCellValue<String>("Smurf"));
 
         assertEquals(2,
                      model.getActionCols().size());
@@ -379,14 +379,14 @@ public class ActionSetFieldColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals(column2,
                      model.getActionCols().get(1));
         assertEquals(45,
-                     model.getData().get(0).get(3).getNumericValue());
+                     model.getData().get(0).get(4).getNumericValue());
         assertEquals("Smurf",
-                     model.getData().get(0).get(4).getStringValue());
+                     model.getData().get(0).get(5).getStringValue());
 
-        assertEquals(5,
+        assertEquals(6,
                      uiModel.getColumns().size());
-        final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(3);
-        final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(5);
         assertEquals("$a",
                      uiModelColumn1_1.getHeaderMetaData().get(0).getTitle());
         assertEquals("age",
@@ -397,16 +397,16 @@ public class ActionSetFieldColumnSynchronizerTest extends BaseSynchronizerTest {
                      uiModelColumn2_1.getHeaderMetaData().get(1).getTitle());
         assertTrue(uiModelColumn1_1 instanceof IntegerUiColumn);
         assertTrue(uiModelColumn2_1 instanceof StringUiColumn);
-        assertEquals(3,
-                     uiModelColumn1_1.getIndex());
         assertEquals(4,
+                     uiModelColumn1_1.getIndex());
+        assertEquals(5,
                      uiModelColumn2_1.getIndex());
         assertEquals(45,
                      uiModel.getRow(0).getCells().get(uiModelColumn1_1.getIndex()).getValue().getValue());
         assertEquals("Smurf",
                      uiModel.getRow(0).getCells().get(uiModelColumn2_1.getIndex()).getValue().getValue());
 
-        uiModel.moveColumnTo(4,
+        uiModel.moveColumnTo(5,
                              uiModelColumn1_1);
 
         assertEquals(2,
@@ -416,14 +416,14 @@ public class ActionSetFieldColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals(column1,
                      model.getActionCols().get(1));
         assertEquals("Smurf",
-                     model.getData().get(0).get(3).getStringValue());
+                     model.getData().get(0).get(4).getStringValue());
         assertEquals(45,
-                     model.getData().get(0).get(4).getNumericValue());
+                     model.getData().get(0).get(5).getNumericValue());
 
-        assertEquals(5,
+        assertEquals(6,
                      uiModel.getColumns().size());
-        final GridColumn<?> uiModelColumn1_2 = uiModel.getColumns().get(3);
-        final GridColumn<?> uiModelColumn2_2 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn1_2 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn2_2 = uiModel.getColumns().get(5);
         assertEquals("$a",
                      uiModelColumn1_2.getHeaderMetaData().get(0).getTitle());
         assertEquals("name",
@@ -434,9 +434,9 @@ public class ActionSetFieldColumnSynchronizerTest extends BaseSynchronizerTest {
                      uiModelColumn2_2.getHeaderMetaData().get(1).getTitle());
         assertTrue(uiModelColumn1_2 instanceof StringUiColumn);
         assertTrue(uiModelColumn2_2 instanceof IntegerUiColumn);
-        assertEquals(4,
+        assertEquals(5,
                      uiModelColumn1_2.getIndex());
-        assertEquals(3,
+        assertEquals(4,
                      uiModelColumn2_2.getIndex());
         assertEquals("Smurf",
                      uiModel.getRow(0).getCells().get(uiModelColumn1_2.getIndex()).getValue().getValue());
@@ -445,7 +445,7 @@ public class ActionSetFieldColumnSynchronizerTest extends BaseSynchronizerTest {
     }
 
     @Test
-    public void testMoveColumnTo_OutOfBounds() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testMoveColumnTo_OutOfBounds() throws VetoException {
         //Add a Pattern to be updated
         final Pattern52 pattern = new Pattern52();
         pattern.setBoundName("$a");
@@ -473,12 +473,12 @@ public class ActionSetFieldColumnSynchronizerTest extends BaseSynchronizerTest {
         modelSynchronizer.appendColumn(column2);
 
         modelSynchronizer.appendRow();
-        uiModel.setCell(0,
-                        3,
-                        new BaseGridCellValue<Integer>(45));
-        uiModel.setCell(0,
-                        4,
-                        new BaseGridCellValue<String>("Smurf"));
+        uiModel.setCellValue(0,
+                             4,
+                             new BaseGridCellValue<Integer>(45));
+        uiModel.setCellValue(0,
+                             5,
+                             new BaseGridCellValue<String>("Smurf"));
 
         assertEquals(2,
                      model.getActionCols().size());
@@ -487,14 +487,14 @@ public class ActionSetFieldColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals(column2,
                      model.getActionCols().get(1));
         assertEquals(45,
-                     model.getData().get(0).get(3).getNumericValue());
+                     model.getData().get(0).get(4).getNumericValue());
         assertEquals("Smurf",
-                     model.getData().get(0).get(4).getStringValue());
+                     model.getData().get(0).get(5).getStringValue());
 
-        assertEquals(5,
+        assertEquals(6,
                      uiModel.getColumns().size());
-        final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(3);
-        final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(5);
         assertEquals("$a",
                      uiModelColumn1_1.getHeaderMetaData().get(0).getTitle());
         assertEquals("age",
@@ -505,16 +505,16 @@ public class ActionSetFieldColumnSynchronizerTest extends BaseSynchronizerTest {
                      uiModelColumn2_1.getHeaderMetaData().get(1).getTitle());
         assertTrue(uiModelColumn1_1 instanceof IntegerUiColumn);
         assertTrue(uiModelColumn2_1 instanceof StringUiColumn);
-        assertEquals(3,
-                     uiModelColumn1_1.getIndex());
         assertEquals(4,
+                     uiModelColumn1_1.getIndex());
+        assertEquals(5,
                      uiModelColumn2_1.getIndex());
         assertEquals(45,
                      uiModel.getRow(0).getCells().get(uiModelColumn1_1.getIndex()).getValue().getValue());
         assertEquals("Smurf",
                      uiModel.getRow(0).getCells().get(uiModelColumn2_1.getIndex()).getValue().getValue());
 
-        uiModel.moveColumnTo(0,
+        uiModel.moveColumnTo(1,
                              uiModelColumn1_1);
 
         assertEquals(2,
@@ -524,14 +524,14 @@ public class ActionSetFieldColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals(column2,
                      model.getActionCols().get(1));
         assertEquals(45,
-                     model.getData().get(0).get(3).getNumericValue());
+                     model.getData().get(0).get(4).getNumericValue());
         assertEquals("Smurf",
-                     model.getData().get(0).get(4).getStringValue());
+                     model.getData().get(0).get(5).getStringValue());
 
-        assertEquals(5,
+        assertEquals(6,
                      uiModel.getColumns().size());
-        final GridColumn<?> uiModelColumn1_2 = uiModel.getColumns().get(3);
-        final GridColumn<?> uiModelColumn2_2 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn1_2 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn2_2 = uiModel.getColumns().get(5);
         assertEquals("$a",
                      uiModelColumn1_2.getHeaderMetaData().get(0).getTitle());
         assertEquals("age",
@@ -542,9 +542,9 @@ public class ActionSetFieldColumnSynchronizerTest extends BaseSynchronizerTest {
                      uiModelColumn2_2.getHeaderMetaData().get(1).getTitle());
         assertTrue(uiModelColumn1_2 instanceof IntegerUiColumn);
         assertTrue(uiModelColumn2_2 instanceof StringUiColumn);
-        assertEquals(3,
-                     uiModelColumn1_2.getIndex());
         assertEquals(4,
+                     uiModelColumn1_2.getIndex());
+        assertEquals(5,
                      uiModelColumn2_2.getIndex());
         assertEquals(45,
                      uiModel.getRow(0).getCells().get(uiModelColumn1_2.getIndex()).getValue().getValue());
